Documentation
¶
Index ¶
Constants ¶
const ( None = Color(iota) Black Red Green Yellow Blue Magenta Cyan White )
Variables ¶
var Writer io.Writer = os.Stdout
Writer is the io.Writer where ANSI escape codes will be written to
Functions ¶
func ChangeColor ¶
ChangeColor sets the foreground and background colors. If the value of the color is None, the corresponding color keeps unchanged. If fgBright or bgBright is set true, corresponding color use bright color. bgBright may be ignored in some OS environment.
func ResetColor ¶
func ResetColor()
ResetColor resets the foreground and background to original colors
Types ¶
Click to show internal directories.
Click to hide internal directories.